@@ -1433,7 +1433,8 @@ main (int argc, char *argv[])
     /* XDM compliant error message */
     if G_UNLIKELY (getuid () != 0) {
 	    /* make sure the pid file doesn't get wiped */
-	    gdm_fail (_("Only root wants to run GDM\n"));
+	    gdm_error (_("Only root wants to run GDM\n"));
+	    exit (-1);
     }
 
     main_loop = g_main_loop_new (NULL, FALSE);
@@ -1448,6 +1449,13 @@ main (int argc, char *argv[])
     sig.sa_flags = SA_RESTART;
     sigemptyset (&sig.sa_mask);
 
+    /* Parse configuration file */
+    gdm_config_parse ();
+
+    /*
+     * Do not call gdm_fail before calling gdm_config_parse ()
+     * since the gdm_fail function uses config data
+     */
     if G_UNLIKELY (sigaction (SIGTERM, &sig, NULL) < 0) 
 	gdm_fail (_("%s: Error setting up %s signal handler: %s"),
 		  "main", "TERM", strerror (errno));
@@ -1459,9 +1467,6 @@ main (int argc, char *argv[])
     /* get the name of the root user */
     gdm_root_user ();
 
-    /* Parse configuration file */
-    gdm_config_parse ();
-
     pidfile = gdm_get_value_string (GDM_KEY_PID_FILE);
 
     /* Check if another gdm process is already running */
@@ -2297,12 +2302,13 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
 			/* send ack */
 			send_slave_ack (d, NULL);
 		}
-	} else if (strcmp (msg, GDM_SOP_SUSPEND_MACHINE) == 0) {
+	} else if (strncmp (msg, GDM_SOP_SUSPEND_MACHINE " ",
+			    strlen (GDM_SOP_SUSPEND_MACHINE " ")) == 0) {
 		GdmDisplay *d;
 		long slave_pid;
 		gboolean sysmenu;
 
-		if (sscanf (msg, GDM_SOP_CHOSEN_THEME " %ld", &slave_pid) != 1)
+		if (sscanf (msg, GDM_SOP_SUSPEND_MACHINE " %ld", &slave_pid) != 1)
 			return;
 		d = gdm_display_lookup (slave_pid);
 
