@@ -1394,7 +1394,7 @@ gdm_chooser_add_host (void)
 
 		msg = g_strdup_printf (_("Cannot find the host \"%s\". "
 		                         "Perhaps you have mistyped it."),
-		                       name);
+		                         name);
 
 		dialog = ve_hig_dialog_new
 		(GTK_WINDOW (chooser) /* parent */,
@@ -1945,7 +1945,7 @@ int
 main (int argc, char *argv[])
 {
     gchar *GdmHosts;
-    gchar **hosts_opt;
+    gchar **hosts_opt = NULL;
     poptContext ctx;
     int nextopt;
     const char *gdm_version;
